@@ -9,13 +9,13 @@ class DebugTwisted(Fixture):
     """Set debug options for Twisted."""
 
     def __init__(self, debug=True):
-        super(DebugTwisted, self).__init__()
+        super().__init__()
         self._debug_setting = debug
 
     def _setUp(self):
         self.useFixture(
-            MonkeyPatch('twisted.internet.defer.Deferred.debug',
-                        self._debug_setting))
+            MonkeyPatch("twisted.internet.defer.Deferred.debug", self._debug_setting)
+        )
         self.useFixture(
-            MonkeyPatch('twisted.internet.base.DelayedCall.debug',
-                        self._debug_setting))
+            MonkeyPatch("twisted.internet.base.DelayedCall.debug", self._debug_setting)
+        )
